==> seedsui-react-2.6.2.tgz: package/es/Progress/Progress.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Counter from './../Counter';

var Progress = (_temp = _class = function (_Component) {
  _inherits(Progress, _Component);

  function Progress(props) {
    _classCallCheck(this, Progress);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.componentDidMount = function () {};

    return _this;
  }

  Progress.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        style = _props.style,
        className = _props.className,
        barStyle = _props.barStyle,
        barClassName = _props.barClassName,
        captionStyle = _props.captionStyle,
        captionClassName = _props.captionClassName,
        percentage = _props.percentage,
        max = _props.max,
        min = _props.min,
        value = _props.value,
        showPercentage = _props.showPercentage,
        children = _props.children,
        others = _objectWithoutProperties(_props, ['style', 'className', 'barStyle', 'barClassName', 'captionStyle', 'captionClassName', 'percentage', 'max', 'min', 'value', 'showPercentage', 'children']);

    // 计算百分比


    var barPercentage = 0;
    var textPercentage = 0;
    if (!isNaN(percentage)) {
      barPercentage = textPercentage = percentage;
    } else if (!isNaN(max) && !isNaN(value)) {
      barPercentage = textPercentage = value / (max - min) * 100;
    }
    if (barPercentage > 100) {
      barPercentage = 100;
    } else if (barPercentage < 0) {
      barPercentage = 0;
    }
    return React.createElement(
      'div',
      _extends({ className: 'progress' + (className ? ' ' + className : ''), style: style }, others),
      React.createElement(
        'span',
        { ref: function ref(el) {
            _this2.$bar = el;
          }, className: 'progress-bar' + (barClassName ? ' ' + barClassName : ''), style: Object.assign({}, barStyle, { width: barPercentage + '%' }) },
        showPercentage && React.createElement(Counter, { duration: 1000, to: textPercentage, from: 0, suffix: '%', className: 'progress-caption' + (captionClassName ? ' ' + captionClassName : ''), style: captionStyle }),
        !showPercentage && React.createElement(Counter, { duration: 1000, to: Number(value), from: min, suffix: '/' + max, className: 'progress-caption' + (captionClassName ? ' ' + captionClassName : ''), style: captionStyle })
      ),
      children
    );
  };

  return Progress;
}(Component), _class.defaultProps = {
  showPercentage: true,
  max: 100,
  min: 0,
  value: 0
}, _temp);
export { Progress as default };
Progress.propTypes = process.env.NODE_ENV !== "production" ? {
  style: PropTypes.object,
  className: PropTypes.string,

  barStyle: PropTypes.object,
  barClassName: PropTypes.string,

  captionClassName: PropTypes.string,
  captionStyle: PropTypes.object,

  percentage: PropTypes.number,
  max: PropTypes.number,
  min: PropTypes.number,
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
  showPercentage: PropTypes.bool,

  children: PropTypes.node
} : {};

==> seedsui-react-3.7.9.tgz: package/es/Progress/Progress.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Counter from './../Counter';

var Progress = (_temp = _class = function (_Component) {
  _inherits(Progress, _Component);

  function Progress(props) {
    _classCallCheck(this, Progress);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.componentDidMount = function () {};

    return _this;
  }

  Progress.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        _props$barAttribute = _props.barAttribute,
        barAttribute = _props$barAttribute === undefined ? {} : _props$barAttribute,
        _props$captionAttribu = _props.captionAttribute,
        captionAttribute = _props$captionAttribu === undefined ? {} : _props$captionAttribu,
        percentage = _props.percentage,
        max = _props.max,
        min = _props.min,
        value = _props.value,
        showPercentage = _props.showPercentage,
        children = _props.children,
        others = _objectWithoutProperties(_props, ['barAttribute', 'captionAttribute', 'percentage', 'max', 'min', 'value', 'showPercentage', 'children']);

    // 计算百分比


    var barPercentage = 0;
    var textPercentage = 0;
    if (!isNaN(percentage)) {
      barPercentage = textPercentage = percentage;
    } else if (!isNaN(max) && !isNaN(value)) {
      barPercentage = textPercentage = value / (max - min) * 100;
    }
    if (barPercentage > 100) {
      barPercentage = 100;
    } else if (barPercentage < 0) {
      barPercentage = 0;
    }
    return React.createElement(
      'div',
      _extends({}, others, { className: 'progress' + (others.className ? ' ' + others.className : ''), style: style }),
      React.createElement(
        'span',
        _extends({ ref: function ref(el) {
            _this2.$bar = el;
          } }, barAttribute, { className: 'progress-bar' + (barAttribute.className ? ' ' + barAttribute.className : ''), style: Object.assign({}, barAttribute.style || {}, { width: barPercentage + '%' }) }),
        showPercentage && React.createElement(Counter, _extends({}, captionAttribute, { className: 'progress-caption' + (captionAttribute.className ? ' ' + captionAttribute.className : ''), duration: 1000, to: textPercentage, from: 0, suffix: '%' })),
        !showPercentage && React.createElement(Counter, _extends({}, captionAttribute, { className: 'progress-caption' + (captionAttribute.className ? ' ' + captionAttribute.className : ''), duration: 1000, to: Number(value), from: min, suffix: '/' + max }))
      ),
      children
    );
  };

  return Progress;
}(Component), _class.defaultProps = {
  showPercentage: true,
  max: 100,
  min: 0,
  value: 0
}, _temp);
export { Progress as default };
Progress.propTypes = process.env.NODE_ENV !== "production" ? {
  barAttribute: PropTypes.object,
  captionAttribute: PropTypes.object,

  percentage: PropTypes.number,
  max: PropTypes.number,
  min: PropTypes.number,
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
  showPercentage: PropTypes.bool,

  children: PropTypes.node
} : {};
